
#ifndef _C12_re580_
#define _C12_re580_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1254_13766(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit580(void);
extern char *(*R2998[])();

#ifdef __cplusplus
}
#endif

#endif
